package com.steerinfo.dil.controller;

import com.steerinfo.dil.model.AmstruckInwardPlan;
import com.steerinfo.dil.service.IAmstruckInwardPlanService;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.DataChange;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiModelProperty;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

//import org.omg.CORBA.OBJ_ADAPTER;

/**
 * AmstruckInwardPlan RESTful接口：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-10-25 03:21
 * 类描述
 * 修订历史：
 * 日期：2021-10-25
 * 作者：generator
 * 参考：
 * 描述：AmstruckInwardPlan RESTful接口
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@RestController
@RequestMapping("/${api.version}/amstruckinwardplan")
public class AmstruckInwardPlanController extends BaseRESTfulController {

    @Autowired
    IAmstruckInwardPlanService amstruckInwardPlanService;
    @Autowired
    ColumnDataUtil columnDataUtil;
    private final SimpleDateFormat sdfDateTime = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
    /**
     *新增运输计划
     */
    @PostMapping("/addTruckPlan")
    public RESTfulResult addTruckPlan(@RequestBody(required=false) Map<String,Object> mapValue) {
        int result = amstruckInwardPlanService.insert(mapValue);
        return success(result);
    }
    /**
     * 删除运输计划
     */
    @PostMapping("/deleteTruckPlan/{planId}")
    public RESTfulResult deleteTruckPlan(@PathVariable("planId") BigDecimal planId) {
        int result = amstruckInwardPlanService.deleteTruckPlan(planId);
        return success(result);

    }

    /*
    停/启用运输计划
     */
    @PostMapping("/changePlanStatus/{planId}")
    public RESTfulResult changePlanStatus(@PathVariable("planId") BigDecimal planId){
        int result = amstruckInwardPlanService.changePlanStatus(planId);
        return success(result);
    }

    /**
     * 完成运输计划
     */
    @PostMapping("/finishTruckPlan/{planId}")
    public RESTfulResult finishTruckPlan(@PathVariable("planId") Integer planId){
        AmstruckInwardPlan amstruckInwardPlan = new AmstruckInwardPlan();
        amstruckInwardPlan.setPlanId(new BigDecimal(planId));
        amstruckInwardPlan.setPlanStatus(new BigDecimal(4));
        int i = amstruckInwardPlanService.updateTruckPlan(amstruckInwardPlan);
        return success(i);
    }

    /**
     * 修改运输计划
     */
    @PostMapping("/updateTruckPlan")
    public RESTfulResult updateTruckPlan(@RequestBody AmstruckInwardPlan amstruckInwardPlan) {
        int result = amstruckInwardPlanService.updateTruckPlan(amstruckInwardPlan);
        return success(result);
    }

    /**
     * 查询修改渲染
     */
    @PostMapping("/selectInwardPlanToUpdate/{planId}")
    public RESTfulResult selectInwardPlanToUpdate(@PathVariable("planId") BigDecimal planId) {
        List<Map<String,Object>> mapList = amstruckInwardPlanService.selectInwardPlanToUpdate(planId);
        return success(mapList);
    }
    /**
     * 下发运输计划
     */
    @PostMapping("/downTruckPlan")
    public RESTfulResult downTruckPlan(@RequestBody List<Map<String, Object>> mapList) {
        int result = amstruckInwardPlanService.downTruckPlan(mapList);
        return success(result);
    }

    /**
     * 接收计划
     */
    @PostMapping("/receiveInwardPlan/{planId}")
    public RESTfulResult receiveInwardPlan(@PathVariable("planId") BigDecimal planId) {
        int result = amstruckInwardPlanService.receiveInwardPlan(planId);
        return success(result);
    }

    /**
     * 展示未下发的运输计划
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiModelProperty(value = "展示运输计划")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "0:257/1,2:258", required = false, dataType = "BigDecimal")
    })
    @PostMapping("/getTruckPlanList")
    public RESTfulResult getTruckPlanList(@RequestBody(required = false) Map<String,Object> mapValue,
                                          Integer pageNum,
                                          Integer pageSize,
                                          Integer apiId,
                                          Integer planStatus,
                                          String carrierId,
                                          Integer planId,
                                          String con) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        if (carrierId != null && !"undefined".equals(carrierId)){
            mapValue.put("carrierId",carrierId);
        }
        if (planId != null && !"undefined".equals(planId.toString())) {
            mapValue.put("planId",new BigDecimal(planId));
        }
        if(con != null && !"null".equals(con)){
            mapValue.put("con","%" + con + "%");
        }
        List<Map<String, Object>> columnList = null;
        PageHelper.startPage(pageNum, pageSize);
        DataChange.queryDataByDateTime(""+mapValue.get("startTime"),""+mapValue.get("endTime"),mapValue,sdfDateTime);
        if(planStatus == 100){
            columnList = amstruckInwardPlanService.getTruckPlanList2(mapValue);
        }else {
            mapValue.put("planStatus",new BigDecimal(planStatus));
            //分页查询数据
            columnList =  amstruckInwardPlanService.getTruckPlanList(mapValue);
        }
        PageListAdd data = columnDataUtil.tableColumnData(apiId, null, columnList);
        return success(data);
    }


    /**
     * 承运商下拉
     * @return
     */
    @GetMapping("/getCarrierList")
    public RESTfulResult getCarrierList() {
        List<Map<String,Object>> mapList = amstruckInwardPlanService.getCarrierList();
        return success(mapList);
    }

    @PostMapping("/getPlanOrder")
    public RESTfulResult getPlanOrder(@RequestBody(required = false) Map<String,Object> mapValue,
                                      Integer pageNum,
                                      Integer pageSize,
                                      Integer apiId,
                                      Integer planId,
                                      Integer orderStatus,
                                      Integer requirementId) {
        if(planId !=null){
            mapValue.put("planId",planId);
        }
        if(requirementId !=null){
            mapValue.put("requirementId",requirementId);
        }
        mapValue.put("orderStatus",orderStatus);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = amstruckInwardPlanService.getPlanOrder(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, null, columnList);
        return success(data);
    }
}
