package com.steerinfo.dil.service.impl;

import com.steerinfo.dil.feign.TmsTruckFeign;
import com.steerinfo.dil.mapper.AmstruckInwardPlanMapper;
import com.steerinfo.dil.mapper.AmstruckRequirementPlanMapper;
import com.steerinfo.dil.mapper.OmstruckOrderMapper;
import com.steerinfo.dil.mapper.OmstruckOrderMaterialMapper;
import com.steerinfo.dil.model.AmstruckInwardPlan;
import com.steerinfo.dil.model.AmstruckRequirementPlan;
import com.steerinfo.dil.model.OmstruckOrder;
import com.steerinfo.dil.model.OmstruckOrderMaterial;
import com.steerinfo.dil.service.IAmstruckInwardPlanService;
import com.steerinfo.dil.service.IAmstruckInwardRequirementService;
import com.steerinfo.dil.util.DataChange;
import com.steerinfo.framework.mapper.IBaseMapper;
import com.steerinfo.framework.service.impl.BaseServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * AmstruckInwardPlan服务实现：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-10-25 03:21
 * 类描述
 * 修订历史：
 * 日期：2021-10-25
 * 作者：generator
 * 参考：
 * 描述：AmstruckInwardPlan服务实现
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@Service(value = "amstruckInwardPlanService")
public class AmstruckInwardPlanServiceImpl extends BaseServiceImpl<AmstruckInwardPlan, BigDecimal> implements IAmstruckInwardPlanService {

    @Autowired
    private AmstruckInwardPlanMapper amstruckInwardPlanMapper;
    @Autowired
    private IAmstruckInwardRequirementService amstruckInwardRequirementService;
    @Autowired
    private AmstruckRequirementPlanMapper amstruckRequirementPlanMapper;
    @Override
    protected IBaseMapper<AmstruckInwardPlan, BigDecimal> getMapper() {
        return amstruckInwardPlanMapper;
    }

    @Autowired
    TmsTruckFeign tmsTruckFeign;

    @Autowired
    OmstruckOrderMapper omstruckOrderMapper;

    @Autowired
    OmstruckOrderMaterialMapper omstruckOrderMaterialMapper;

    @Transactional
    @Override
    public int insert(Map<String,Object> mapValue) {
        AmstruckInwardPlan amstruckInwardPlan = new AmstruckInwardPlan();
        BigDecimal planId = amstruckInwardPlanMapper.selectOtherId();
        //设置主键
        amstruckInwardPlan.setPlanId(planId);
        //获取承运商id，车数
        BigDecimal carrierId=new BigDecimal(mapValue.get("carrierId").toString());
        BigDecimal planTruckNumber = DataChange.dataToBigDecimal(mapValue.get("planTruckNumber"));
        if(planTruckNumber.intValue() != 0){
            amstruckInwardPlan.setPlanTruckNumber(planTruckNumber);
        }
        amstruckInwardPlan.setCarrierId(carrierId);
        amstruckInwardPlan.setPlanNumber(DataChange.generateEightDigitsNumber("YSJH",planId.intValue()));
        //设置计划状态为未下发
        amstruckInwardPlan.setPlanStatus(new BigDecimal(0));
        if(mapValue.get("addBilletRequirement") != null) {
            amstruckInwardPlan.setPlanStatus(new BigDecimal(3));
            mapValue.put("planId",planId);
            addBilletOrder(mapValue);
        }
        // 设置常规字段
        // 设置常规字段
        amstruckInwardPlan.setInsertTime(new Date());
        amstruckInwardPlan.setInsertUsername("admin");
        amstruckInwardPlan.setInsertUpdateRemark("无");
        amstruckInwardPlan.setDeleted(new BigDecimal(0));
        int i = amstruckInwardPlanMapper.insertSelective(amstruckInwardPlan);
        //新增需求计划中间表
        AmstruckRequirementPlan amstruckRequirementPlan = new AmstruckRequirementPlan();
        //xu qiu ID
        BigDecimal requirementId = new BigDecimal(mapValue.get("requirementId").toString());
        BigDecimal requirementPlanId = amstruckRequirementPlanMapper.selectOtherId();
        amstruckRequirementPlan.setRequirementPlanId(requirementPlanId);
        amstruckRequirementPlan.setPlanId(planId);
        amstruckRequirementPlan.setRequirementId(requirementId);
        amstruckRequirementPlan.setInsertTime(new Date());
        amstruckRequirementPlan.setInsertUsername("admin");
        amstruckRequirementPlan.setInsertUpdateRemark("无");
        //在中间表中将需求与计划绑定
        i += amstruckRequirementPlanMapper.insertSelective(amstruckRequirementPlan);
        return i;
    }

    public int addBilletOrder(Map<String,Object> mapValue) {
        int result = 0;
        List<Map<String,Object>> mapList = (List<Map<String, Object>>) mapValue.get("capacityList");
        BigDecimal planId = DataChange.dataToBigDecimal(mapValue.get("planId")) ;
        String orgCode =(String) mapValue.get("orgCode");
        Integer carrierId = (Integer) mapValue.get("carrierId");
        for (Map<String,Object> orderMap : mapList) {
            OmstruckOrder omstruckOrder = new OmstruckOrder();
            BigDecimal capacityId = DataChange.dataToBigDecimal(orderMap.get("capacityId"));
            BigDecimal orderId = omstruckOrderMapper.selectMaxId();
            // 添加总实绩
            Map<String,Object> orderIdMap = new HashMap<>();
            orderIdMap.put("orderId",orderId);
            tmsTruckFeign.addTotalResult(orderIdMap);
            omstruckOrder.setOrderId(orderId);
            omstruckOrder.setOrderPlanId(planId);
            String orderNumber = DataChange.generateEightDigitsNumber("WYSDD", orderId.intValue());
            omstruckOrder.setOrderNumber(orderNumber);
            omstruckOrder.setOrderIssueTime(new Date());
            omstruckOrder.setOrderStatus(new BigDecimal(4));
            omstruckOrder.setOptionerCode(orgCode);
            omstruckOrder.setCapacityId(capacityId);
            omstruckOrder.setInsertTime(new Date());
            omstruckOrder.setUpdateTime(new Date());
            omstruckOrder.setInsertUpdateRemark("无");
            omstruckOrder.setDeleted(new BigDecimal(100));
            omstruckOrder.setOrderType(new BigDecimal(11));
            omstruckOrder.setCarrierId(new BigDecimal(carrierId));
            result +=omstruckOrderMapper.insertSelective(omstruckOrder);
            OmstruckOrderMaterial omstruckOrderMaterial = new OmstruckOrderMaterial();
            BigDecimal orderMaterialId = omstruckOrderMaterialMapper.selectMaxId();
            BigDecimal materialId = DataChange.dataToBigDecimal(mapValue.get("materialId"));
            omstruckOrderMaterial.setOrderMaterialId(orderMaterialId);
            omstruckOrderMaterial.setOrderId(orderId);
            omstruckOrderMaterial.setMaterialId(materialId);
            omstruckOrderMaterial.setOrderMaterialNumber(DataChange.dataToBigDecimal(mapValue.get("count")));
            if (mapValue.get("materialWeight") != null) {
                omstruckOrderMaterial.setOrderMaterialWeight(DataChange.dataToBigDecimal(mapValue.get("materialWeight")));
            }
            omstruckOrderMaterial.setMaterialLuno(mapValue.get("heatNo").toString());
            omstruckOrderMaterial.setInsertTime(new Date());
            omstruckOrderMaterial.setUpdateTime(new Date());
            result +=omstruckOrderMaterialMapper.insertSelective(omstruckOrderMaterial);
        }
        return result;
    }


    @Override
    public List<Map<String, Object>> getTruckPlanList(Map<String, Object> mapValue) {
        BigDecimal planStatus = (BigDecimal)mapValue.get("planStatus");
//        在mapValue中存储当前时间
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        mapValue.put("newTime",format.format(new Date()));
        List<Map<String,Object>> mapList;
        if (planStatus.intValue() == 0) {
            mapList = amstruckInwardPlanMapper.getTruckPlanList(mapValue);
        }
        else {
            mapList = amstruckInwardPlanMapper.getIssuedPlanList(mapValue);
        }
        return mapList;
    }

    public List<Map<String, Object>> getTruckPlanList2(Map<String, Object> mapValue) {
        return amstruckInwardPlanMapper.getIssuedPlanList2(mapValue);
    }

    /**
     * 删除计划
     * @param planId
     * @return
     */
    @Override
    public int deleteTruckPlan(BigDecimal planId) {
        AmstruckInwardPlan amstruckInwardPlan = amstruckInwardPlanMapper.selectByPrimaryKey(planId);
        amstruckInwardPlan.setDeleted(new BigDecimal(1));
        int result = amstruckInwardPlanMapper.updateByPrimaryKeySelective(amstruckInwardPlan);
        return result;
    }

    /**
     * 修改计划
     * @param amstruckInwardPlan
     * @return
     */
    @Override
    public int updateTruckPlan(AmstruckInwardPlan amstruckInwardPlan) {
        amstruckInwardPlan.setUpdateTime(new Date());
        amstruckInwardPlan.setUpdateUsername("admin");
        int result = amstruckInwardPlanMapper.updateByPrimaryKeySelective(amstruckInwardPlan);
        return result;
    }

    /**
     * 下发计划
     * @param mapList
     * @return
     */
    @Override
    public int downTruckPlan(List<Map<String,Object>> mapList) {
        int result = 0;
        for (Map<String,Object> map : mapList) {
            Integer planId = (Integer) map.get("planId");
            AmstruckInwardPlan amstruckInwardPlan = amstruckInwardPlanMapper.selectByPrimaryKey(new BigDecimal(planId));
            amstruckInwardPlan.setPlanStatus(new BigDecimal(2));
            amstruckInwardPlan.setPlanIssueName("admin");
            amstruckInwardPlan.setPlanIssueTime(new Date());
            result += amstruckInwardPlanMapper.updateByPrimaryKeySelective(amstruckInwardPlan);
        }
        return result;
    }

    /**
     * 主键查询修改渲染
     * @param planId
     * @return
     */
    @Override
    public List<Map<String, Object>> selectInwardPlanToUpdate(BigDecimal planId) {
        return amstruckInwardPlanMapper.selectInwardPlanToUpdate(planId);
    }

    /**
     * 承运商下拉
     * @return
     */
    @Override
    public List<Map<String, Object>> getCarrierList() {
        return amstruckInwardPlanMapper.getCarrierList();
    }

    /**
     * 接收计划
     * @param planId
     * @return
     */
    @Override
    public int receiveInwardPlan(BigDecimal planId) {
        AmstruckInwardPlan amstruckInwardPlan = amstruckInwardPlanMapper.selectByPrimaryKey(planId);
        amstruckInwardPlan.setPlanStatus(new BigDecimal(2));
        int result = amstruckInwardPlanMapper.updateByPrimaryKeySelective(amstruckInwardPlan);
        return result;
    }

    //停用计划
    @Override
    public int changePlanStatus(BigDecimal planId) {
        AmstruckInwardPlan amstruckInwardPlan = amstruckInwardPlanMapper.selectByPrimaryKey(planId);
        amstruckInwardPlan.setPlanEableStatus(new BigDecimal(0));
        int result = amstruckInwardPlanMapper.updateByPrimaryKeySelective(amstruckInwardPlan);
        return result;
    }

    @Override
    public List<Map<String, Object>> getPlanOrder(Map<String, Object> mapValue) {
        return amstruckInwardPlanMapper.getPlanOrder(mapValue);
    }
}
