package com.steerinfo.dil.util;

import com.steerinfo.dil.mapper.SaleLogMapper;
import com.steerinfo.dil.model.SaleLog;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

@Component
public class SaleLogUtil {
    @Autowired
    private SaleLogMapper saleLogMapper;

    public final static int INSERT = 1;

    public final static int UPDATE = 2;

    public final static int DELETE = 3;

    public final static int OPEN = 4;

    public final static int CLOSE = 5;

    /**
     * 插入运输订单的操作日志
     * @param orderId
     * @param descriptoin
     * @param oprationType 操作类型
     * @param map 可以传null
     * @return
     */
    public int logOrder(BigDecimal orderId,String descriptoin,Map<String,Object> map,int oprationType){
        try{
            SaleLog saleLog=new SaleLog();
            saleLog.setResultId(saleLogMapper.selectMaxId());
            saleLog.setOrderId(orderId);
            saleLog.setDescription(descriptoin);
            //saleLog.setJsonData(""+map);
            saleLog.setInsertTime(new Date());
            saleLog.setInsertUsername(getUserName(map));
            switch (oprationType){
                case INSERT:
                    saleLog.setOprationType("新增");
                    break;
                case UPDATE:
                    saleLog.setOprationType("修改");
                    break;
                case DELETE:
                    saleLog.setOprationType("删除");
                    break;
                case OPEN:
                    saleLog.setOprationType("启用");
                    break;
                case CLOSE:
                    saleLog.setOprationType("关闭");
                    break;
                default:
                    saleLog.setOprationType("未知操作");
            }
            return saleLogMapper.insertSelective(saleLog);
        }catch (Exception e){
            e.printStackTrace();
            return -1;
        }
    }


    //插入销售订单操作日志
    public int logSaleOrder(BigDecimal saleOrderId,String descriptoin,String userName,int oprationType) {
        try {
            //List<BigDecimal> orderIds = saleLogMapper.getOrderIds(orderNumber);
            List<SaleLog> list = new ArrayList<>();
            //for(BigDecimal orderId:orderIds){
            SaleLog saleLog = new SaleLog();
            saleLog.setResultId(saleLogMapper.selectMaxId());
            //saleLog.setOrderId(orderId);
            saleLog.setSaleOrderId(saleOrderId);
            saleLog.setDescription(descriptoin);
            //saleLog.setJsonData(""+map);
            saleLog.setInsertTime(new Date());
            saleLog.setInsertUsername(userName);
            switch (oprationType) {
                case INSERT:
                    saleLog.setOprationType("新增");
                    break;
                case UPDATE:
                    saleLog.setOprationType("修改");
                    break;
                case DELETE:
                    saleLog.setOprationType("删除");
                    break;
                case OPEN:
                    saleLog.setOprationType("启用");
                    break;
                case CLOSE:
                    saleLog.setOprationType("关闭");
                    break;
                default:
                    saleLog.setOprationType("未知操作");
            }
            list.add(saleLog);
            //}
            return saleLogMapper.batchInsert(list);
        } catch (Exception e) {
            e.printStackTrace();
            return -1;
        }
    }
    /**
     * 处理插入用户名
     * @param map
     * @return
     */
    private String getUserName(Map<String,Object> map){
        try{
            if(map==null){
                return "system";
            }else if(map.get("userName")!=null){
                return ""+map.get("userName");
            }else if(map.get("userId")!=null){
                return saleLogMapper.getUserNameById(map);
            }else{
                return "未知用户";
            }
        }catch (Exception e){
            e.printStackTrace();
            return "未知用户";
        }
    }
}
